@@ -10,21 +10,21 @@
 // Needs to be be before X11/Intrinsic.h because of qtextstream.h
 #include <phonon/MediaObject>
 
+#include <X11/Intrinsic.h> /* Intrinsics Definitions*/
+#include <X11/StringDefs.h> /* Standard Name-String definitions*/
 #include <X11/Xmd.h>
-#include <X11/Intrinsic.h>     /* Intrinsics Definitions*/
-#include <X11/StringDefs.h>    /* Standard Name-String definitions*/
-#include <X11/extensions/xtestext1.h>    /* Standard Name-String definitions*/
-#include <X11/extensions/XTest.h>    /* Standard Name-String definitions*/
+#include <X11/extensions/XTest.h> /* Standard Name-String definitions*/
+#include <X11/extensions/xtestext1.h> /* Standard Name-String definitions*/
 #include <fixx11h.h>
 
 #include <QAbstractEventDispatcher>
 #include <QApplication>
-#include <QDesktopWidget>
-#include <QIcon>
-#include <QMenu>
-#include <QStandardPaths>
 #include <QFile>
 #include <QFileInfo>
+#include <QIcon>
+#include <QMenu>
+#include <QScreen>
+#include <QStandardPaths>
 
 #include <KConfig>
 #include <KConfigGroup>
@@ -44,8 +44,8 @@ int leftButton;
 int rightButton;
 
 /**
-* Gnarly X functions
-*/
+ * Gnarly X functions
+ */
 void queryPointer(Window *pidRoot, int *pnRx, int *pnRy, int *pnX, int *pnY, unsigned int *puMask);
 int CursorHasMoved(int minMovement);
 void getMouseButtons();
@@ -58,41 +58,40 @@ void LeftUp();
 // Declarations
 Display *display;
 
-
 void KMouseTool::init_vars()
 {
     continue_timer = 1;
     tick_count = 0;
-    max_ticks = dwell_time+1;
+    max_ticks = dwell_time + 1;
     mouse_is_down = false;
 
     loadOptions();
 
     // If the ~/.mousetool directory doesn't exist, create it
-    mSoundFileName = QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral( "sounds/mousetool_tap.wav" ));
+    mSoundFileName = QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, QStringLiteral("sounds/mousetool_tap.wav"));
     mplayer = Phonon::createPlayer(Phonon::AccessibilityCategory);
     mplayer->setParent(this);
 
     // find application file
-    appfilename = QStandardPaths::findExecutable(QStringLiteral( "kmousetool" ));
+    appfilename = QStandardPaths::findExecutable(QStringLiteral("kmousetool"));
 
     // find the user's autostart directory
     autostartdirname = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QStringLiteral("/autostart-scripts/");
 
-    QDesktopWidget *d = QApplication::desktop();
-    int w = d->width();
-    int h = d->height();
-    MTStroke::setUpperLeft(0,0);
-    MTStroke::setUpperRight(w-1,0);
-    MTStroke::setLowerLeft(0,h-1);
-    MTStroke::setLowerRight(w-1,h-1);
+    auto screenSize = screen()->availableGeometry();
+    int w = screenSize.width();
+    int h = screenSize.height();
+    MTStroke::setUpperLeft(0, 0);
+    MTStroke::setUpperRight(w - 1, 0);
+    MTStroke::setLowerLeft(0, h - 1);
+    MTStroke::setLowerRight(w - 1, h - 1);
 
     buttonQuit = buttonBox->addButton(QString(), QDialogButtonBox::RejectRole);
 }
 
 void KMouseTool::resetSettings()
 {
-    cbDrag ->setChecked(smart_drag_on);
+    cbDrag->setChecked(smart_drag_on);
     cbStart->setChecked(isAutostart());
     cbClick->setChecked(playSound);
     cbStroke->setChecked(strokesEnabled);
@@ -104,7 +103,7 @@ void KMouseTool::resetSettings()
 
 void KMouseTool::setDefaultSettings()
 {
-    cbDrag ->setChecked(false);
+    cbDrag->setChecked(false);
     cbStart->setChecked(false);
     cbClick->setChecked(false);
     cbStroke->setChecked(false);
@@ -114,8 +113,7 @@ void KMouseTool::setDefaultSettings()
     settingsChanged();
 }
 
-
-void KMouseTool::timerEvent( QTimerEvent * )
+void KMouseTool::timerEvent(QTimerEvent *)
 {
     if (!mousetool_is_running)
         return;
@@ -128,7 +126,7 @@ void KMouseTool::timerEvent( QTimerEvent * )
     max_ticks = dwell_time + drag_time;
     stroke.addPt(currentXPosition, currentYPosition);
 
-    moving = moving?CursorHasMoved(1):CursorHasMoved(min_movement);
+    moving = moving ? CursorHasMoved(1) : CursorHasMoved(min_movement);
     if (moving) {
         if (mousetool_just_started) {
             mousetool_just_started = false;
@@ -139,11 +137,11 @@ void KMouseTool::timerEvent( QTimerEvent * )
         return;
     }
 
-    if (tick_count<max_ticks)
+    if (tick_count < max_ticks)
         tick_count++;
 
     // If the mouse has paused ...
-    if (tick_count==dwell_time) {
+    if (tick_count == dwell_time) {
         int strokeType = stroke.getStrokeType();
         getMouseButtons();
 
@@ -159,12 +157,12 @@ void KMouseTool::timerEvent( QTimerEvent * )
         }
         if (strokeType == MTStroke::DontClick)
             return;
-        if (strokeType==MTStroke::bumped_mouse)
+        if (strokeType == MTStroke::bumped_mouse)
             return;
 
-        if (strokeType==MTStroke::RightClick || strokeType==MTStroke::UpperRightStroke)
+        if (strokeType == MTStroke::RightClick || strokeType == MTStroke::UpperRightStroke)
             RightClick();
-        else if (strokeType==MTStroke::DoubleClick || strokeType==MTStroke::LowerLeftStroke)
+        else if (strokeType == MTStroke::DoubleClick || strokeType == MTStroke::LowerLeftStroke)
             DoubleClick();
         else
             normalClick();
@@ -202,10 +200,11 @@ void KMouseTool::playTickSound()
 }
 
 KMouseTool::KMouseTool(QWidget *parent, const char *name)
- : QWidget(parent), helpMenu(new KHelpMenu(nullptr))
+    : QWidget(parent)
+    , helpMenu(new KHelpMenu(nullptr))
 {
     setupUi(this);
-    setObjectName( QLatin1String( name ));
+    setObjectName(QLatin1String(name));
     init_vars();
     resetSettings();
 
@@ -231,8 +230,8 @@ KMouseTool::KMouseTool(QWidget *parent, const char *name)
     mousetool_just_started = true;
 
     startTimer(100);
-    trayIcon = new KMouseToolTray (this);
-    updateStartStopText ();
+    trayIcon = new KMouseToolTray(this);
+    updateStartStopText();
     connect(trayIcon, &KMouseToolTray::startStopSelected, this, &KMouseTool::startStopSelected);
     connect(trayIcon, &KMouseToolTray::configureSelected, this, &KMouseTool::configureSelected);
     connect(trayIcon, &KMouseToolTray::aboutSelected, this, &KMouseTool::aboutSelected);
@@ -252,8 +251,7 @@ void getMouseButtons()
 {
     unsigned char buttonMap[3];
     const int buttonCount = XGetPointerMapping(display, buttonMap, 3);
-    switch (buttonCount)
-    {
+    switch (buttonCount) {
     case 0:
     case 1:
         // ### should not happen
@@ -301,21 +299,20 @@ void LeftUp()
     XTestFakeButtonEvent(display, leftButton, false, 0);
 }
 
-
 void queryPointer(Window *pidRoot, int *pnRx, int *pnRy, int *pnX, int *pnY, unsigned int *puMask)
 {
     Window id2, idRoot;
     int screen_num;
 
     screen_num = DefaultScreen(display);
-    idRoot = RootWindow(display,screen_num);
+    idRoot = RootWindow(display, screen_num);
     XQueryPointer(display, idRoot, &idRoot, &id2, pnRx, pnRy, pnX, pnY, puMask);
 
     *pidRoot = idRoot;
 }
 
 // return 1 if cursor has moved, 0 otherwise
-int CursorHasMoved (int minMovement)
+int CursorHasMoved(int minMovement)
 {
     static int nOldRootX = -1;
     static int nOldRootY = -1;
@@ -328,9 +325,9 @@ int CursorHasMoved (int minMovement)
     queryPointer(&idRootWin, &nRootX, &nRootY, &nWinX, &nWinY, &uintMask);
 
     int nRes = 0;
-    if ((nRootX>nOldRootX?nRootX-nOldRootX:nOldRootX-nRootX) >= minMovement)
+    if ((nRootX > nOldRootX ? nRootX - nOldRootX : nOldRootX - nRootX) >= minMovement)
         nRes = 1;
-    if ((nRootY>nOldRootY?nRootY-nOldRootY:nOldRootY-nRootY) >= minMovement)
+    if ((nRootY > nOldRootY ? nRootY - nOldRootY : nOldRootY - nRootY) >= minMovement)
         nRes = 1;
 
     currentXPosition = nRootX;
@@ -345,20 +342,19 @@ int CursorHasMoved (int minMovement)
 }
 // End mouse monitoring and event creation code
 
-
 bool KMouseTool::isAutostart()
 {
     QString sym = autostartdirname;
-    sym += QLatin1String( "kmousetool" ); // sym is now full path to symlink
+    sym += QLatin1String("kmousetool"); // sym is now full path to symlink
     QFileInfo fi(sym);
 
     return fi.exists();
 }
 
-void KMouseTool::setAutostart (bool start)
+void KMouseTool::setAutostart(bool start)
 {
     QString sym = autostartdirname;
-    sym += QLatin1String( "kmousetool" ); // sym is now full path to symlink
+    sym += QLatin1String("kmousetool"); // sym is now full path to symlink
     QFileInfo fi(sym);
 
     if (start) {
@@ -375,23 +371,23 @@ bool KMouseTool::applySettings()
     int drag, dwell;
 
     dwell = dwellTimeEdit->value();
-    drag = dragTimeEdit->value() ;
+    drag = dragTimeEdit->value();
 
     // The drag time must be less than the dwell time
-    if ( dwell < drag) {
+    if (dwell < drag) {
         KMessageBox::sorry(this, i18n("The drag time must be less than or equal to the dwell time."), i18n("Invalid Value"));
         return false;
     }
 
     // if we got here, we must be okay.
-    min_movement   = movementEdit->value();
-    smart_drag_on  = cbDrag->isChecked();
-    playSound      = cbClick->isChecked();
+    min_movement = movementEdit->value();
+    smart_drag_on = cbDrag->isChecked();
+    playSound = cbClick->isChecked();
     strokesEnabled = cbStroke->isChecked();
-    setAutostart (cbStart->isChecked());
+    setAutostart(cbStart->isChecked());
 
     dwell_time = dwell;
-    drag_time  = drag;
+    drag_time = drag;
     tick_count = max_ticks;
 
     saveOptions();
@@ -407,14 +403,14 @@ void KMouseTool::loadOptions()
     playSound = cfg.readEntry("AudibleClick", false);
     smart_drag_on = cfg.readEntry("SmartDrag", false);
 
-    dwell_time = cfg.readEntry("DwellTime",5);
-    drag_time = cfg.readEntry("DragTime",3);
-    min_movement = cfg.readEntry("Movement",5);
+    dwell_time = cfg.readEntry("DwellTime", 5);
+    drag_time = cfg.readEntry("DragTime", 3);
+    min_movement = cfg.readEntry("Movement", 5);
     strokesEnabled = cfg.readEntry("strokesEnabled", false);
 
     QPoint p;
-    int x = cfg.readEntry("x",0);
-    int y = cfg.readEntry("y",0);
+    int x = cfg.readEntry("x", 0);
+    int y = cfg.readEntry("y", 0);
     p.setX(x);
     p.setY(y);
     move(p);
@@ -457,34 +453,25 @@ void KMouseTool::updateStartStopText()
 
 bool KMouseTool::newSettings()
 {
-    return ((dwell_time != dwellTimeEdit->value()) ||
-            (drag_time != dragTimeEdit->value()) ||
-            (min_movement != movementEdit->value()) ||
-            (smart_drag_on != cbDrag->isChecked()) ||
-            (playSound != cbClick->isChecked()) ||
-            (strokesEnabled != cbStroke->isChecked()) ||
-            (isAutostart() != cbStart->isChecked()));
+    return ((dwell_time != dwellTimeEdit->value()) || (drag_time != dragTimeEdit->value()) || (min_movement != movementEdit->value())
+            || (smart_drag_on != cbDrag->isChecked()) || (playSound != cbClick->isChecked()) || (strokesEnabled != cbStroke->isChecked())
+            || (isAutostart() != cbStart->isChecked()));
 }
 
 bool KMouseTool::defaultSettings()
 {
-    return ((5 == dwellTimeEdit->value()) &&
-            (3 == dragTimeEdit->value()) &&
-            (5 == movementEdit->value()) &&
-            !cbDrag->isChecked() &&
-            !cbClick->isChecked() &&
-            !cbStroke->isChecked() &&
-            !cbStart->isChecked());
+    return ((5 == dwellTimeEdit->value()) && (3 == dragTimeEdit->value()) && (5 == movementEdit->value()) && !cbDrag->isChecked() && !cbClick->isChecked()
+            && !cbStroke->isChecked() && !cbStart->isChecked());
 }
 
 /******** SLOTS **********/
 
 // Value or state changed
-void KMouseTool::settingsChanged ()
+void KMouseTool::settingsChanged()
 {
-    buttonBoxSettings->button(QDialogButtonBox::Reset)->setEnabled (newSettings());
-    buttonBoxSettings->button(QDialogButtonBox::Apply)->setEnabled (newSettings());
-    buttonBoxSettings->button(QDialogButtonBox::RestoreDefaults)->setDisabled (defaultSettings());
+    buttonBoxSettings->button(QDialogButtonBox::Reset)->setEnabled(newSettings());
+    buttonBoxSettings->button(QDialogButtonBox::Apply)->setEnabled(newSettings());
+    buttonBoxSettings->button(QDialogButtonBox::RestoreDefaults)->setDisabled(defaultSettings());
 }
 
 // Buttons within the dialog
@@ -517,13 +504,15 @@ void KMouseTool::helpSelected()
 
 void KMouseTool::closeSelected()
 {
-    if (newSettings())
-    {
-        int answer = KMessageBox::questionYesNoCancel (this,
-                                                       i18n("There are unsaved changes in the active module.\nDo you want to apply the changes before closing the configuration window or discard the changes?"),
-                                                       i18n("Closing Configuration Window"),
-                                                       KStandardGuiItem::apply(), KStandardGuiItem::discard(),
-                                                       KStandardGuiItem::cancel(), QStringLiteral( "AutomaticSave" ));
+    if (newSettings()) {
+        int answer = KMessageBox::questionYesNoCancel(this,
+                                                      i18n("There are unsaved changes in the active module.\nDo you want to apply the changes before closing "
+                                                           "the configuration window or discard the changes?"),
+                                                      i18n("Closing Configuration Window"),
+                                                      KStandardGuiItem::apply(),
+                                                      KStandardGuiItem::discard(),
+                                                      KStandardGuiItem::cancel(),
+                                                      QStringLiteral("AutomaticSave"));
         if (answer == KMessageBox::Yes)
             applySettings();
         else if (answer == KMessageBox::No)
@@ -537,17 +526,18 @@ void KMouseTool::closeSelected()
 
 void KMouseTool::quitSelected()
 {
-    if (newSettings())
-    {
-        int answer = KMessageBox::questionYesNoCancel (this,
-                                                       i18n("There are unsaved changes in the active module.\nDo you want to apply the changes before quitting KMousetool or discard the changes?"),
-                                                       i18n("Quitting KMousetool"),
-                                                       KStandardGuiItem::apply(), KStandardGuiItem::discard(),
-                                                       KStandardGuiItem::cancel(), QStringLiteral( "AutomaticSave" ));
+    if (newSettings()) {
+        int answer = KMessageBox::questionYesNoCancel(
+            this,
+            i18n("There are unsaved changes in the active module.\nDo you want to apply the changes before quitting KMousetool or discard the changes?"),
+            i18n("Quitting KMousetool"),
+            KStandardGuiItem::apply(),
+            KStandardGuiItem::discard(),
+            KStandardGuiItem::cancel(),
+            QStringLiteral("AutomaticSave"));
         if (answer == KMessageBox::Yes)
             applySettings();
-        if (answer != KMessageBox::Cancel)
-        {
+        if (answer != KMessageBox::Cancel) {
             saveOptions();
             qApp->quit();
         }
@@ -570,24 +560,24 @@ void KMouseTool::aboutSelected()
     helpMenu->aboutApplication();
 }
 
-
-
-KMouseToolTray::KMouseToolTray (QWidget *parent) : KStatusNotifierItem(parent)
+KMouseToolTray::KMouseToolTray(QWidget *parent)
+    : KStatusNotifierItem(parent)
 {
     setStatus(KStatusNotifierItem::Active);
-    startStopAct = contextMenu()->addAction (i18nc("Start tracking the mouse", "&Start"), this, &KMouseToolTray::startStopSelected);
+    startStopAct = contextMenu()->addAction(i18nc("Start tracking the mouse", "&Start"), this, &KMouseToolTray::startStopSelected);
     contextMenu()->addSeparator();
-    QAction* act;
-    act = contextMenu()->addAction (i18n("&Configure KMouseTool..."), this, &KMouseToolTray::configureSelected);
-    act->setIcon(QIcon::fromTheme(QStringLiteral( "configure" )));
+    QAction *act;
+    act = contextMenu()->addAction(i18n("&Configure KMouseTool..."), this, &KMouseToolTray::configureSelected);
+    act->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
     contextMenu()->addSeparator();
-    act = contextMenu()->addAction (i18n("KMousetool &Handbook"), this, &KMouseToolTray::helpSelected);
-    act->setIcon(QIcon::fromTheme(QStringLiteral( "help-contents" )));
-    act = contextMenu()->addAction (i18n("&About KMouseTool"), this, &KMouseToolTray::aboutSelected);
-    act->setIcon(QIcon::fromTheme(QStringLiteral( "kmousetool" )));
+    act = contextMenu()->addAction(i18n("KMousetool &Handbook"), this, &KMouseToolTray::helpSelected);
+    act->setIcon(QIcon::fromTheme(QStringLiteral("help-contents")));
+    act = contextMenu()->addAction(i18n("&About KMouseTool"), this, &KMouseToolTray::aboutSelected);
+    act->setIcon(QIcon::fromTheme(QStringLiteral("kmousetool")));
 }
 
-KMouseToolTray::~KMouseToolTray() {
+KMouseToolTray::~KMouseToolTray()
+{
 }
 
 void KMouseToolTray::updateStartStopText(bool mousetool_is_running)
@@ -596,10 +586,10 @@ void KMouseToolTray::updateStartStopText(bool mousetool_is_running)
 
     if (mousetool_is_running) {
         startStopAct->setText(i18n("&Stop"));
-        icon = KIconLoader::global()->loadIcon(QStringLiteral( "kmousetool_on" ), KIconLoader::Small);
+        icon = KIconLoader::global()->loadIcon(QStringLiteral("kmousetool_on"), KIconLoader::Small);
     } else {
         startStopAct->setText(i18nc("Start tracking the mouse", "&Start"));
-        icon = KIconLoader::global()->loadIcon(QStringLiteral( "kmousetool_off" ), KIconLoader::Small);
+        icon = KIconLoader::global()->loadIcon(QStringLiteral("kmousetool_off"), KIconLoader::Small);
     }
-    setIconByPixmap (icon);
+    setIconByPixmap(icon);
 }
