@@ -4,7 +4,6 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #include "kmousetool.h"
 
 #include <KAboutData>
@@ -15,21 +14,20 @@
 
 #include <QCommandLineParser>
 
-static const char description[] = I18N_NOOP("KMouseTool");
-
 int main(int argc, char *argv[])
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     // enable high dpi support
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
-
+#endif
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("kmousetool");
 
     KAboutData aboutData(QStringLiteral("kmousetool"),
                          i18n("KMouseTool"),
                          QStringLiteral(KMOUSETOOL_VERSION),
-                         i18n(description),
+                         i18n("KMouseTool"),
                          KAboutLicense::GPL,
                          i18n("(c) 2002-2003, Jeff Roush\n(c) 2003 Gunnar Schmidt "),
                          QString(),
